==> jc-1.4.0.tar.gz: gnu/java/net/protocol/jar/Connection.h <==
// public final class gnu.java.net.protocol.jar.Connection

// class file dependencies
// @dep_class f056c21d31123006 gnu_java_net_protocol_jar_Connection
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class aafc7525546c2332 java_net_JarURLConnection
// @dep_class 1042c111741aa488 java_net_URLConnection

// header file dependencies
// @dep_header java_net_JarURLConnection

#include "java/net/JarURLConnection.h"

#ifndef _JC_gnu_java_net_protocol_jar_Connection_H_
#define _JC_gnu_java_net_protocol_jar_Connection_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_net_URL$object;
struct _jc_java_util_jar_JarEntry$object;
struct _jc_java_util_jar_JarFile$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_jar_Connection$sub_refs	_jc_gnu_java_net_protocol_jar_Connection$sub_refs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection$sub_nonrefs	_jc_gnu_java_net_protocol_jar_Connection$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection$refs	_jc_gnu_java_net_protocol_jar_Connection$refs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection$nonrefs	_jc_gnu_java_net_protocol_jar_Connection$nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection$object	_jc_gnu_java_net_protocol_jar_Connection$object;

typedef const struct _jc_gnu_java_net_protocol_jar_Connection$vmethods	_jc_gnu_java_net_protocol_jar_Connection$vmethods;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection$vtable	_jc_gnu_java_net_protocol_jar_Connection$vtable;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection$vtype	_jc_gnu_java_net_protocol_jar_Connection$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_jar_Connection$method$_init$52b89ab562ab928f(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *, struct _jc_java_net_URL$object *);

// Virtual methods
extern void _jc_gnu_java_net_protocol_jar_Connection$method$connect$47946c90596538d1(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *);
extern jint _jc_gnu_java_net_protocol_jar_Connection$method$getContentLength$b5dadbc29a008b07(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *);
extern struct _jc_java_io_InputStream$object *_jc_gnu_java_net_protocol_jar_Connection$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *);
extern struct _jc_java_util_jar_JarFile$object *_jc_gnu_java_net_protocol_jar_Connection$method$getJarFile$84e91656fcfa4ca4(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_jar_Connection$method_info$connect$47946c90596538d1;
extern _jc_method _jc_gnu_java_net_protocol_jar_Connection$method_info$getContentLength$b5dadbc29a008b07;
extern _jc_method _jc_gnu_java_net_protocol_jar_Connection$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_gnu_java_net_protocol_jar_Connection$method_info$getJarFile$84e91656fcfa4ca4;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_jar_Connection$vmethods {
	void	(*connect$47946c90596538d1)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *);
	jint	(*getContentLength$b5dadbc29a008b07)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *);
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *);
	struct _jc_java_util_jar_JarFile$object	*(*getJarFile$84e91656fcfa4ca4)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_jar_Connection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLConnection$vmethods	java_net_URLConnection;
	_jc_java_net_JarURLConnection$vmethods	java_net_JarURLConnection;
	_jc_gnu_java_net_protocol_jar_Connection$vmethods	gnu_java_net_protocol_jar_Connection;
};

// Vtype
struct _jc_gnu_java_net_protocol_jar_Connection$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_jar_Connection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Connection$sub_refs {
	struct _jc_java_util_jar_JarFile$object	*jar__5ffile;
	struct _jc_java_util_jar_JarEntry$object	*jar__5fentry;
	struct _jc_java_net_URL$object	*jar__5furl;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Connection$refs {
    _jc_gnu_java_net_protocol_jar_Connection$sub_refs	gnu_java_net_protocol_jar_Connection;
    _jc_java_net_JarURLConnection$sub_refs	java_net_JarURLConnection;
    _jc_java_net_URLConnection$sub_refs	java_net_URLConnection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Connection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Connection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLConnection$sub_nonrefs	java_net_URLConnection;
    _jc_java_net_JarURLConnection$sub_nonrefs	java_net_JarURLConnection;
    _jc_gnu_java_net_protocol_jar_Connection$sub_nonrefs	gnu_java_net_protocol_jar_Connection;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_jar_Connection$object {
	_jc_gnu_java_net_protocol_jar_Connection$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_jar_Connection$vtype	*vtype;
	_jc_gnu_java_net_protocol_jar_Connection$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_jar_Connection$vtype _jc_gnu_java_net_protocol_jar_Connection$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_jar_Connection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_jar_Connection$class_object;

#endif	/* _JC_gnu_java_net_protocol_jar_Connection_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/jar/Connection.h <==
// public final class gnu.java.net.protocol.jar.Connection

// class file dependencies
// @dep_class f056c21d31123006 gnu_java_net_protocol_jar_Connection
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class aafc7525546c2332 java_net_JarURLConnection
// @dep_class 1042c111741aa488 java_net_URLConnection

// header file dependencies
// @dep_header java_net_JarURLConnection

#include "java/net/JarURLConnection.h"

#ifndef _JC_gnu_java_net_protocol_jar_Connection_H_
#define _JC_gnu_java_net_protocol_jar_Connection_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_net_URL$object;
struct _jc_java_util_jar_JarEntry$object;
struct _jc_java_util_jar_JarFile$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_jar_Connection$sub_refs	_jc_gnu_java_net_protocol_jar_Connection$sub_refs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection$sub_nonrefs	_jc_gnu_java_net_protocol_jar_Connection$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection$refs	_jc_gnu_java_net_protocol_jar_Connection$refs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection$nonrefs	_jc_gnu_java_net_protocol_jar_Connection$nonrefs;
typedef struct _jc_gnu_java_net_protocol_jar_Connection$object	_jc_gnu_java_net_protocol_jar_Connection$object;

typedef const struct _jc_gnu_java_net_protocol_jar_Connection$vmethods	_jc_gnu_java_net_protocol_jar_Connection$vmethods;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection$vtable	_jc_gnu_java_net_protocol_jar_Connection$vtable;
typedef const struct _jc_gnu_java_net_protocol_jar_Connection$vtype	_jc_gnu_java_net_protocol_jar_Connection$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_jar_Connection$method$_init$52b89ab562ab928f(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_protocol_jar_Connection$method$connect$47946c90596538d1(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_jar_Connection$method$getContentLength$b5dadbc29a008b07(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_gnu_java_net_protocol_jar_Connection$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_jar_JarFile$object *_jc_gnu_java_net_protocol_jar_Connection$method$getJarFile$84e91656fcfa4ca4(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_jar_Connection$method_info$connect$47946c90596538d1;
extern _jc_method _jc_gnu_java_net_protocol_jar_Connection$method_info$getContentLength$b5dadbc29a008b07;
extern _jc_method _jc_gnu_java_net_protocol_jar_Connection$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_gnu_java_net_protocol_jar_Connection$method_info$getJarFile$84e91656fcfa4ca4;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_jar_Connection$vmethods {
	void	(*connect$47946c90596538d1)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *) _JC_JCNI_ATTR;
	jint	(*getContentLength$b5dadbc29a008b07)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_jar_JarFile$object	*(*getJarFile$84e91656fcfa4ca4)(_jc_env *, struct _jc_gnu_java_net_protocol_jar_Connection$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_jar_Connection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLConnection$vmethods	java_net_URLConnection;
	_jc_java_net_JarURLConnection$vmethods	java_net_JarURLConnection;
	_jc_gnu_java_net_protocol_jar_Connection$vmethods	gnu_java_net_protocol_jar_Connection;
};

// Vtype
struct _jc_gnu_java_net_protocol_jar_Connection$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_jar_Connection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Connection$sub_refs {
	struct _jc_java_util_jar_JarFile$object	*jar__5ffile;
	struct _jc_java_util_jar_JarEntry$object	*jar__5fentry;
	struct _jc_java_net_URL$object	*jar__5furl;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Connection$refs {
    _jc_gnu_java_net_protocol_jar_Connection$sub_refs	gnu_java_net_protocol_jar_Connection;
    _jc_java_net_JarURLConnection$sub_refs	java_net_JarURLConnection;
    _jc_java_net_URLConnection$sub_refs	java_net_URLConnection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_jar_Connection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_jar_Connection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLConnection$sub_nonrefs	java_net_URLConnection;
    _jc_java_net_JarURLConnection$sub_nonrefs	java_net_JarURLConnection;
    _jc_gnu_java_net_protocol_jar_Connection$sub_nonrefs	gnu_java_net_protocol_jar_Connection;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_jar_Connection$object {
	_jc_gnu_java_net_protocol_jar_Connection$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_jar_Connection$vtype	*vtype;
	_jc_gnu_java_net_protocol_jar_Connection$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_jar_Connection$vtype _jc_gnu_java_net_protocol_jar_Connection$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_jar_Connection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_jar_Connection$class_object;

#endif	/* _JC_gnu_java_net_protocol_jar_Connection_H_ */
